@@ -10,6 +10,10 @@
 #include <sys/stat.h>
 #include <sys/statvfs.h>
 
+#ifdef STATX_BTIME
+    #include <sys/syscall.h>
+#endif
+
 #ifdef __USE_LARGEFILE64
     #define stat stat64
     #define statvfs statvfs64
@@ -263,9 +267,9 @@ static void detectStats(FFDisk* disk)
     }
 
     disk->createTime = 0;
-    #ifdef FF_HAVE_STATX
+    #ifdef SYS_statx
     struct statx stx;
-    if (statx(0, disk->mountpoint.chars, 0, STATX_BTIME, &stx) == 0 && (stx.stx_mask & STATX_BTIME))
+    if (syscall(SYS_statx, 0, disk->mountpoint.chars, 0, STATX_BTIME, &stx) == 0 && (stx.stx_mask & STATX_BTIME) && stx.stx_btime.tv_sec > 685065600 /*birth of Linux*/)
         disk->createTime = (uint64_t)((stx.stx_btime.tv_sec * 1000) + (stx.stx_btime.tv_nsec / 1000000));
     #endif
 
@@ -287,7 +291,7 @@ const char* ffDetectDisksImpl(FFDiskOptions* options, FFlist* disks)
     {
         if (__builtin_expect(options->folders.length > 0, false))
         {
-            if (!ffDiskMatchMountpoint(&options->folders, device->mnt_dir))
+            if (!ffStrbufSeparatedContainS(&options->folders, device->mnt_dir, FF_DISK_FOLDER_SEPARATOR))
                 continue;
         }
         else if(!isPhysicalDevice(device))
