@@ -18,10 +18,10 @@ static uint32_t getSQLite3Int(const char* dbPath, const char* query, const char*
     return num_elements;
 }
 
-void ffDetectPackagesImpl(FFPackagesResult* result, FF_MAYBE_UNUSED FFPackagesOptions* options)
+void ffDetectPackagesImpl(FFPackagesResult* result, FFPackagesOptions* options)
 {
     if (!(options->disabled & FF_PACKAGES_FLAG_PKG_BIT))
-    {
         result->pkg = getSQLite3Int(FASTFETCH_TARGET_DIR_ROOT "/var/db/pkg/local.sqlite", "SELECT count(*) FROM packages", "pkg");
-    }
+    if (!(options->disabled & FF_PACKAGES_FLAG_MPORT_BIT))
+        result->mport = getSQLite3Int(FASTFETCH_TARGET_DIR_ROOT "/var/db/mport/master.db", "SELECT count(*) FROM packages", "mport");
 }
