@@ -5,7 +5,7 @@
 
 #define FF_PLAYER_MODULE_NAME "Player"
 
-void ffPrintPlayer(FFPlayerOptions* options);
+bool ffPrintPlayer(FFPlayerOptions* options);
 void ffInitPlayerOptions(FFPlayerOptions* options);
 void ffDestroyPlayerOptions(FFPlayerOptions* options);
 
