@@ -1,3 +1,6 @@
+#pragma once
+
+#include "fastfetch.h"
 #include "common/time.h"
 
 static inline const char* ffFindFileName(const char* file)
